# tapyr-cmd

TAPyR-CMD is a bunch of command line tools to use with [TAPIR](https://github.com/tap-ir/tapir), based on on the [TAPyR](ttps://github.com/tap-ir/tapyr) python library.

The user documentation is available [here](https://tap-ir.github.io/#/?id=command-line).

## Installation

```
pip install tapyr-cmd 
```
